/* Front end styles */
.wp-block-a8c-event {
  display: flex;
  flex-direction: row;
  padding: 18px;
  font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', sans-serif;
  box-shadow: inset 0 0 0 4px rgba(0, 0, 0, 0.1); }
  .wp-block-a8c-event.aligncenter {
    display: flex;
    text-align: left; }
  .wp-block-a8c-event .event__datebox {
    float: left;
    width: 40px;
    height: 40px;
    background: black;
    color: white;
    margin: 0 18px 18px 0;
    padding: 4px;
    text-align: center; }
    .wp-block-a8c-event .event__datebox > span {
      display: block;
      margin: 0;
      line-height: 16px; }
    .wp-block-a8c-event .event__datebox span:first-child {
      font-weight: bold;
      font-size: 12px; }
  .wp-block-a8c-event .event__title {
    font-weight: 800;
    line-height: 40px;
    clear: none; }
  .wp-block-a8c-event .event__title,
  .wp-block-a8c-event .event__time,
  .wp-block-a8c-event .event__location {
    margin-top: 0;
    margin-bottom: 18px;
    hyphens: auto;
    overflow-wrap: break-word; }
  .wp-block-a8c-event .event__description {
    margin-top: 18px; }
  .wp-block-a8c-event .event__label {
    display: inline-block;
    min-width: 80px;
    opacity: 0.5; }
  .wp-block-a8c-event .event__location {
    display: flex; }
  .wp-block-a8c-event .event__details {
    flex: 2; }
  .wp-block-a8c-event .event__image {
    flex: 1;
    margin-left: 18px; }
  .wp-block-a8c-event .event__image--save {
    float: right; }
