/* Editor styles */
.wp-block-a8c-event .event__date-select {
  display: inline; }
  .wp-block-a8c-event .event__date-select .components-button {
    height: auto;
    background: white; }

.editor-styles-wrapper .wp-block-a8c-event,
.editor-styles-wrapper .wp-block[data-align="center"] > .wp-block-a8c-event {
  text-align: left; }
  .editor-styles-wrapper .wp-block-a8c-event p,
  .editor-styles-wrapper .wp-block[data-align="center"] > .wp-block-a8c-event p {
    font-family: inherit; }
  .editor-styles-wrapper .wp-block-a8c-event .event__title,
  .editor-styles-wrapper .wp-block[data-align="center"] > .wp-block-a8c-event .event__title {
    margin: 0 0 18px;
    font-weight: 800;
    line-height: 40px; }
